@@ -107,8 +107,15 @@ pickdep <- function(fitted, main, bound = TRUE, plot = TRUE,
     A <- function(w){
       ans <- rep(NA, length(w))
       idx <- which((w <= 0) | (w > 1))
-      w <- w[-idx]
-      ans[-idx] <- ((1-w)^(1/alpha) + w^(1/alpha))^alpha
+
+      if (length(idx) > 0){
+        w <- w[-idx]
+        ans[-idx] <- ((1-w)^(1/alpha) + w^(1/alpha))^alpha
+      }
+
+      else
+        ans <- ((1-w)^(1/alpha) + w^(1/alpha))^alpha
+      
       return(ans)
     }
   }
@@ -118,8 +125,15 @@ pickdep <- function(fitted, main, bound = TRUE, plot = TRUE,
     A <- function(w){
       ans <- rep(NA, length(w))
       idx <- which((w <= 0) | (w > 1))
-      w <- w[-idx]
-      ans[-idx] <- 1 - ((1-w)^(-alpha) + w^(-alpha))^(-1/alpha)
+
+      if (length(idx) > 0){
+        w <- w[-idx]
+        ans[-idx] <- 1 - ((1-w)^(-alpha) + w^(-alpha))^(-1/alpha)
+      }
+
+      else
+        ans <- 1 - ((1-w)^(-alpha) + w^(-alpha))^(-1/alpha)
+      
       return(ans)
     }
   }
@@ -131,9 +145,17 @@ pickdep <- function(fitted, main, bound = TRUE, plot = TRUE,
     A <- function(w){
       ans <- rep(NA, length(w))
       idx <- which((w <= 0) | (w > 1))
-      w <- w[-idx]
-      ans[-idx] <- (1 - asCoef1)*(1-w) + (1 - asCoef2) * w +
-        ( (asCoef1 * (1-w))^(1/alpha) + (asCoef2 * w)^(1/alpha) )^alpha
+
+      if (length(idx) > 0){
+        w <- w[-idx]
+        ans[-idx] <- (1 - asCoef1)*(1-w) + (1 - asCoef2) * w +
+          ( (asCoef1 * (1-w))^(1/alpha) + (asCoef2 * w)^(1/alpha) )^alpha
+      }
+
+      else
+        ans <- (1 - asCoef1)*(1-w) + (1 - asCoef2) * w +
+          ( (asCoef1 * (1-w))^(1/alpha) + (asCoef2 * w)^(1/alpha) )^alpha
+    
       return(ans)
     }
   }
@@ -145,9 +167,17 @@ pickdep <- function(fitted, main, bound = TRUE, plot = TRUE,
     A <- function(w){
       ans <- rep(NA, length(w))
       idx <- which((w <= 0) | (w > 1))
-      w <- w[-idx]
-      ans[-idx] <- 1 - ( ((1-w)*asCoef1)^(-alpha) +
-                        (w*asCoef2)^(-alpha) )^(-1/alpha)
+
+      if (length(idx) > 0){
+        w <- w[-idx]
+        ans[-idx] <- 1 - ( ((1-w)*asCoef1)^(-alpha) +
+                          (w*asCoef2)^(-alpha) )^(-1/alpha)
+      }
+
+      else
+        ans <- 1 - ( ((1-w)*asCoef1)^(-alpha) +
+                    (w*asCoef2)^(-alpha) )^(-1/alpha)
+      
       return(ans)
     }
   }
@@ -157,8 +187,15 @@ pickdep <- function(fitted, main, bound = TRUE, plot = TRUE,
     A <- function(w){
       ans <- rep(NA, length(w))
       idx <- which((w <= 0) | (w > 1))
-      w <- w[-idx]
-      ans[-idx] <- 1 - w * (1-w) * alpha
+
+      if (length(idx) > 0){
+        w <- w[-idx]
+        ans[-idx] <- 1 - w * (1-w) * alpha
+      }
+
+      else
+        ans <- 1 - w * (1-w) * alpha
+      
       return(ans)
     }
   }
@@ -169,9 +206,17 @@ pickdep <- function(fitted, main, bound = TRUE, plot = TRUE,
     A <- function(w){
       ans <- rep(NA, length(w))
       idx <- which((w <= 0) | (w > 1))
-      w <- w[-idx]
-      ans[-idx] <- 1 - (alpha + 2 * asCoef) * w +
-        (alpha + 3 * asCoef)* w^2 - asCoef * w^3
+
+      if (length(idx) > 0){
+        w <- w[-idx]
+        ans[-idx] <- 1 - (alpha + 2 * asCoef) * w +
+          (alpha + 3 * asCoef)* w^2 - asCoef * w^3
+      }
+
+      else
+        ans <-  1 - (alpha + 2 * asCoef) * w +
+          (alpha + 3 * asCoef)* w^2 - asCoef * w^3
+      
       return(ans)
     }
   }
